@@ -18,7 +18,7 @@
 #
 #=============================================================================
 
-package Term::CLI::Argument::Filename 0.055001;
+package Term::CLI::Argument::Filename 0.055002;
 
 use 5.014;
 use warnings;
@@ -36,7 +36,7 @@ sub complete {
     my ( $self, $text ) = @_;
 
     my $func_ref = $self->term->Attribs->{filename_completion_function}
-        or return $self->_glob_complete($text);
+        or return $self->glob_complete($text);
 
     if ($func_ref) {
         my $state = 0;
@@ -49,7 +49,7 @@ sub complete {
     }
 }
 
-sub _glob_complete {
+sub glob_complete {
     my ( $self, $text ) = @_;
     my @list = bsd_glob("$text*");
 
@@ -91,7 +91,7 @@ Term::CLI::Argument::Filename - class for file name arguments in Term::CLI
 
 =head1 VERSION
 
-version 0.055001
+version 0.055002
 
 =head1 SYNOPSIS
 
@@ -136,22 +136,33 @@ Complete the (partial) filename in I<TEXT>. The I<STATE> HashRef is
 ignored.
 
 If present, this uses the C<filename_completion_function> function listed
-in L<Term::ReadLine>'s C<Attribs>, otherwise it will use its own
-implementation based on L<bsd_glob from File::Glob|File::Glob/bsd_glob>.
+in L<Term::ReadLine>'s C<Attribs>, otherwise it will use the
+L<glob_complete|/glob_complete> method.
 
 Not every C<Term::ReadLine> implementation implements its own
 filename completion function. The ones that do will have the
 C<Attrib-E<gt>{filename_completion_function}> attribute set.
 L<Term::ReadLine::Gnu> does this, while L<Term::ReadLine::Perl> doesn't.
 
+=item B<glob_complete> ( I<TEXT> )
+
+=item B<glob_complete> ( I<TEXT>, I<STATE> )
+
+Complete the (partial) filename in I<TEXT>. The I<STATE> HashRef is
+ignored.
+
+Implementation uses L<bsd_glob from File::Glob|File::Glob/bsd_glob> and
+applies some decorations on the filenames based on their type, similar
+to what L<Term::ReadLine::Gnu|Term::ReadLine::Gnu> does.
+
 =back
 
 =head1 SEE ALSO
 
-L<Term::CLI::Argument>(3p),
-L<Term::ReadLine::Gnu>(3p),
-L<File::Glob>(3p),
-L<Term::CLI>(3p).
+L<Term::CLI::Argument|Term::CLI::Argument>(3p),
+L<Term::ReadLine::Gnu|Term::ReadLine::Gnu>(3p),
+L<File::Glob|File::Glob>(3p),
+L<Term::CLI|Term::CLI>(3p).
 
 =head1 AUTHOR
 
