@@ -245,7 +245,7 @@ push @commands, Term::CLI::Command->new(
                 Term::CLI::Argument::Bool->new(
                     name         => 'bool',
                     true_values  => [qw( 1 true on yes ok )],
-                    false_values => [qw( 1 false off no never )],
+                    false_values => [qw( 0 false off no never )],
                 )
 
             ],
@@ -349,7 +349,7 @@ $term->add_command(@commands);
 
 say "\n[Welcome to BSSH]";
 while ( defined( my $line = $term->readline ) ) {
-    $term->execute($line);
+    $term->execute_line($line);
 }
 print "\n";
 execute_exit( $term, 0 );
